package com.meerkat.laura.fakescannerapp;

import android.content.Intent;
import android.os.AsyncTask;
import android.os.StrictMode;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Base64;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.google.protobuf.BoolValue;
import com.google.protobuf.ByteString;
import com.google.protobuf.InvalidProtocolBufferException;
import com.google.zxing.integration.android.IntentIntegrator;
import com.google.zxing.integration.android.IntentResult;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.Socket;
import java.net.URL;
import java.nio.ByteBuffer;

import javax.net.ssl.HttpsURLConnection;

import RestClient.APIService;
import RestClient.ApiUtils;
import meerkat.protobuf.PollingStation;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;


public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private Button scanBtn;
    private TextView formatTxt, contentTxt, responseTxt;

    private APIService mAPIService;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        scanBtn = (Button)findViewById(R.id.scan_button);
        formatTxt = (TextView)findViewById(R.id.scan_format);
        contentTxt = (TextView)findViewById(R.id.scan_content);
        responseTxt = (TextView)findViewById(R.id.server_response);

        mAPIService = ApiUtils.getAPIService();
        scanBtn.setOnClickListener(this);
    }

    public void onClick(View v){
        if(v.getId()==R.id.scan_button){
            IntentIntegrator scanIntegrator = new IntentIntegrator(this);
            formatTxt.setText("Initiating scan...");
            scanIntegrator.initiateScan();
        }
    }

    public void onActivityResult(int requestCode, int resultCode, Intent intent) {
        IntentResult scanningResult = IntentIntegrator.parseActivityResult(requestCode, resultCode, intent);
        if (scanningResult != null) {
            String scanContent = scanningResult.getContents();
            byte[] rawBytes = scanningResult.getRawBytes();
            String scanFormat = scanningResult.getFormatName();
            formatTxt.setText("FORMAT: " + scanFormat);
            contentTxt.setText("CONTENT: " + scanContent + "sending data to server...");
//            sendPost(rawBytes);
            sendPost(scanContent);
        } else{
            Toast toast = Toast.makeText(getApplicationContext(),
                    "No scan data received!", Toast.LENGTH_SHORT);
            toast.show();
        }
    }

//    public void sendPost(byte[] body) {
public void sendPost(String scanContent) {

        try {
            PollingStation.ScannedData scannedData = PollingStation.ScannedData.parseFrom(Base64.decode(scanContent.getBytes(), Base64.DEFAULT));
    //
    //        PollingStation.ScannedData scannedData = PollingStation.ScannedData.newBuilder()
    //                .setChannel(ByteString.copyFrom(body))
    //                .build();

            mAPIService.sendScan(scannedData).enqueue(new Callback<BoolValue>() {
                @Override
                public void onResponse(Call<BoolValue> call, Response<BoolValue> response) {

                    if(response.isSuccessful()) {
                        showResponse("response="+response.body().getValue());
                        Log.i("MainActivity", "post submitted to API.");
                    } else {
                        showResponse("Error HTTP code="+response.code());
                        Log.i("MainActivity", "post submitted to API but respnse with http error code.");
                    }
                }

                @Override
                public void onFailure(Call<BoolValue> call, Throwable t) {
                    Log.e("MainActivity", "Unable to submit post to API.");
                }
            });
        } catch (InvalidProtocolBufferException e) {
            e.printStackTrace();
        }
    }

    public void showResponse(String response) {
        responseTxt.setText(response);
    }

}
