package meerkat.pollingstation;

import com.google.protobuf.BoolValue;
import meerkat.protobuf.BulletinBoardAPI;
import meerkat.protobuf.PollingStation;
import meerkat.rest.Constants;
import meerkat.rest.ProtobufMessageBodyReader;
import meerkat.rest.ProtobufMessageBodyWriter;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.Response;

import static meerkat.pollingstation.PollingStationConstants.POLLING_STATION_WEB_SCANNER_ERROR_PATH;
import static meerkat.pollingstation.PollingStationConstants.POLLING_STATION_WEB_SCANNER_SCAN_PATH;

/**
 * Created by Laura on 3/20/2017.
 */
public class ScannerClientAPI {
    private Client client;
    private WebTarget webTarget;

    public ScannerClientAPI(String address, String sub_address, int port, String path) {
        client = ClientBuilder.newClient();
        client.register(ProtobufMessageBodyReader.class);
        client.register(ProtobufMessageBodyWriter.class);
        webTarget = client.target(address + ":" + port)
                .path(sub_address).path(path);
    }

    /**
     * Sends the scanned data to the polling station server
     * @param scannedData
     * @return boolean value: true if the data was sent successfully, false otherwise
     */
    public boolean sendScan(PollingStation.ScannedData scannedData) {
        Response response = webTarget.request(Constants.MEDIATYPE_PROTOBUF).post(Entity.entity(scannedData, Constants.MEDIATYPE_PROTOBUF));
        BoolValue res = response.readEntity(BoolValue.class);
        response.close();
        return res.getValue();
    }

    /**
     * Sends the error message to the polling station server
     * @param errorMsg
     * @return boolean value: true if the error message was sent successfully, false otherwise
     */
    public boolean sendError(PollingStation.ErrorMsg errorMsg) {
        Response response = webTarget.request(Constants.MEDIATYPE_PROTOBUF).post(Entity.entity(errorMsg, Constants.MEDIATYPE_PROTOBUF));
        BoolValue res = response.readEntity(BoolValue.class);
        response.close();
        return res.getValue();
    }
}
